pub struct PoolCreatedAndInitialized {
    pub token_0: Pubkey,
    pub token_1: Pubkey,
    pub fee: u32,
    pub tick_spacing: u16,
    pub pool_state: Pubkey,
    pub sqrt_price_x32: u64,
    pub tick: i32,
}
Emitted when a pool is created and initialized with a starting price

Fields

token_0: Pubkey

The first token of the pool by address sort order

token_1: Pubkey

The second token of the pool by address sort order

fee: u32

The fee collected upon every swap in the pool, denominated in hundredths of a bip

tick_spacing: u16

The minimum number of ticks between initialized ticks

pool_state: Pubkey

The address of the created pool

sqrt_price_x32: u64

The initial sqrt price of the pool, as a Q32.32

tick: i32

The initial tick of the pool, i.e. log base 1.0001 of the starting price of the pool