pub struct DecreaseLiquidityEvent {
pub token_id: Pubkey,
pub liquidity: u64,
pub amount_0: u64,
pub amount_1: u64,
}Expand description
Emitted when liquidity is decreased for a position NFT
Fields
token_id: PubkeyThe ID of the token for which liquidity was decreased
liquidity: u64The amount by which liquidity for the NFT position was decreased
amount_0: u64The amount of token_0 that was accounted for the decrease in liquidity
amount_1: u64The amount of token_1 that was accounted for the decrease in liquidity