pub struct IncreaseLiquidityEvent {
pub token_id: Pubkey,
pub liquidity: u64,
pub amount_0: u64,
pub amount_1: u64,
}Expand description
Emitted when liquidity is increased for a position NFT. Also emitted when a token is minted
Fields
token_id: PubkeyThe ID of the token for which liquidity was increased
liquidity: u64The amount by which liquidity for the NFT position was increased
amount_0: u64The amount of token_0 that was paid for the increase in liquidity
amount_1: u64The amount of token_1 that was paid for the increase in liquidity