Struct cyclos_core::states::pool::PoolCreatedAndInitialized
source · [−]pub struct PoolCreatedAndInitialized {
pub token_0: Pubkey,
pub token_1: Pubkey,
pub fee: u32,
pub tick_spacing: u16,
pub pool_state: Pubkey,
pub sqrt_price_x32: u64,
pub tick: i32,
}Expand description
Emitted when a pool is created and initialized with a starting price
Fields
token_0: PubkeyThe first token of the pool by address sort order
token_1: PubkeyThe second token of the pool by address sort order
fee: u32The fee collected upon every swap in the pool, denominated in hundredths of a bip
tick_spacing: u16The minimum number of ticks between initialized ticks
pool_state: PubkeyThe address of the created pool
sqrt_price_x32: u64The initial sqrt price of the pool, as a Q32.32
tick: i32The initial tick of the pool, i.e. log base 1.0001 of the starting price of the pool